pecos.qeclib.steane.qec.qec\_3parallel
======================================

.. automodule:: pecos.qeclib.steane.qec.qec_3parallel











   .. rubric:: Classes

   .. autosummary::

      ParallelFlagQECActiveCorrection
